*************************************************
  Pygame Logos Page
*************************************************

Pygame Logos
============

These logos are available for use in your own game projects.
Please put them up wherever you see fit. The logo was created
by TheCorruptor on July 29, 2001 and upscaled by Mega_JC on
August 29, 2021.

.. container:: fullwidth

    .. image:: _static/pygame_logo.png

    | `pygame_logo.svg <_static/pygame_logo.svg>`_
    | `pygame_logo.png <_static/pygame_logo.png>`_ - 1561 x 438

    .. image:: _static/pygame_lofi.png

    | `pygame_lofi.svg <_static/pygame_lofi.svg>`_
    | `pygame_lofi.png <_static/pygame_lofi.png>`_ - 1561 x 438

    .. image:: _static/pygame_powered.png

    | `pygame_powered.svg <_static/pygame_powered.svg>`_
    | `pygame_powered.png <_static/pygame_powered.png>`_ - 1617 x 640

    .. image:: _static/pygame_tiny.png

    | `pygame_tiny.png <_static/pygame_tiny.png>`_ - 214 x 60

    .. image:: _static/pygame_powered_lowres.png

    | `pygame_powered_lowres.png <_static/pygame_powered_lowres.png>`_ - 101 x 40


There is a higher resolution layered photoshop image
available `here <https://www.pygame.org/ftp/pygame_logo.psd>`_. *(1.3 MB)*

Legacy logos
------------

.. container:: fullwidth

    `legacy_logos.zip <_static/legacy_logos.zip>`_ - 50.1 KB